@@ -1,5 +1,6 @@
 from ormar.exceptions import ModelDefinitionError, ModelNotSet, MultipleMatches, NoMatch
-from ormar.fields import (
+from ormar.protocols import QuerySetProtocol, RelationProtocol  # noqa: I100
+from ormar.fields import (  # noqa: I100
     BigInteger,
     Boolean,
     Date,
@@ -17,6 +18,7 @@ from ormar.fields import (
     UniqueColumns,
 )
 from ormar.models import Model
+from ormar.models.metaclass import ModelMeta
 from ormar.queryset import QuerySet
 from ormar.relations import RelationType
 
@@ -28,8 +30,7 @@ class UndefinedType:  # pragma no cover
 
 Undefined = UndefinedType()
 
-
-__version__ = "0.3.11"
+__version__ = "0.4.1"
 __all__ = [
     "Integer",
     "BigInteger",
@@ -54,4 +55,7 @@ __all__ = [
     "Undefined",
     "UUID",
     "UniqueColumns",
+    "QuerySetProtocol",
+    "RelationProtocol",
+    "ModelMeta",
 ]
