@@ -1,5 +1,6 @@
 import inspect
-from typing import Dict, List, Set, TYPE_CHECKING, Type, TypeVar, Union
+from collections import OrderedDict
+from typing import Dict, List, Sequence, Set, TYPE_CHECKING, Type, TypeVar, Union
 
 import ormar
 from ormar.exceptions import RelationshipInstanceError
@@ -11,6 +12,8 @@ if TYPE_CHECKING:  # pragma no cover
     from ormar import Model
     from ormar.models import NewBaseModel
 
+    T = TypeVar("T", bound=Model)
+
 Field = TypeVar("Field", bound=BaseField)
 
 
@@ -135,7 +138,7 @@ class ModelTableProxy:
                 if field.to == related.__class__ or field.to.Meta == related.Meta:
                     return name
         # fallback for not registered relation
-        if register_missing:
+        if register_missing:  # pragma nocover
             expand_reverse_relationships(related.__class__)  # type: ignore
             return ModelTableProxy.resolve_relation_name(
                 item, related, register_missing=False
@@ -177,13 +180,20 @@ class ModelTableProxy:
         return new_kwargs
 
     @classmethod
-    def merge_instances_list(cls, result_rows: List["Model"]) -> List["Model"]:
+    def merge_instances_list(cls, result_rows: Sequence["Model"]) -> Sequence["Model"]:
         merged_rows: List["Model"] = []
-        for index, model in enumerate(result_rows):
-            if index > 0 and model is not None and model.pk == merged_rows[-1].pk:
-                merged_rows[-1] = cls.merge_two_instances(model, merged_rows[-1])
-            else:
-                merged_rows.append(model)
+        grouped_instances: OrderedDict = OrderedDict()
+
+        for model in result_rows:
+            grouped_instances.setdefault(model.pk, []).append(model)
+
+        for group in grouped_instances.values():
+            model = group.pop(0)
+            if group:
+                for next_model in group:
+                    model = cls.merge_two_instances(next_model, model)
+            merged_rows.append(model)
+
         return merged_rows
 
     @classmethod
